<?php
namespace MASCOTCORENOVIO\Shortcodes\FeaturesBox;

use MASCOTCORENOVIO\Shortcodes\Lib;

/**
 * class SC_Features_Box
 * @package MASCOTCORENOVIO\Shortcodes\FeaturesBox;
 */
class SC_Features_Box implements Lib\Mascot_Core_Novio_Interface_Shortcodes {
	
	/**
	 * @var shortcode_base
	 */
	private $shortcode_base;

	/**
	 * construct
	 */
	public function __construct() {
		$this->shortcode_base = 'tm_features_box';
		add_action('init', array($this, 'MapShortCodeVC'), 998);
	}

	/**
	 * Returns shortcode_base for shortcode
	 */
	public function getShortCodeBase() {
		return $this->shortcode_base;
	}

	/**
	 * Maps shortcode to Visual Composer
	 */
	public function MapShortCodeVC() {
		$title_options = esc_html__( 'Title Options', 'mascot-core' );
		$group_content_options = esc_html__( 'Content Options', 'mascot-core' );

		if(function_exists('vc_map')) {
			$vc_map = array(
				'name'		=> esc_html__( 'Features Box', 'mascot-core' ),
				'base'		=>$this->shortcode_base,
				'category'	=> esc_html__( 'by TM', 'mascot-core' ),
				'icon'		=> 'mascot-vc-icons vc-icon-before-after',
				'allowed_container_element' => 'vc_row',
				'params'	=>array(
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Custom CSS class", 'mascot-core' ),
						"param_name"	=> "custom_css_class",
						"description"	=> esc_html__( 'To style particular content element.', 'mascot-core' ),
					),
					array(
						'type'			=> 'dropdown',
						"heading"		=> esc_html__( "Design Style", 'mascot-core' ),
						"param_name"	=> "design_style",
						"description"	=> "",
						'value'			=> array(
							esc_html__( "Current Theme Style 1", 'mascot-core' )   => 'current-theme-style1',
							esc_html__( "Current Theme Style 2", 'mascot-core' )   => 'current-theme-style2',
						),
						'save_always'   => true,
						'admin_label'   => true,
					),
					array(
						'type'			=> 'attach_image',
						"heading"		=> esc_html__( "Featured Image", 'mascot-core' ),
						"param_name"	=> "featured_image",
						"description"	=> esc_html__( 'Upload featured image.', 'mascot-core' ),
						'save_always'   => true,
						'admin_label'   => true,
					),
					array(
						'type'			=> 'attach_image',
						"heading"		=> esc_html__( "Featured Image on Hover", 'mascot-core' ),
						"param_name"	=> "featured_image_hover",
						"description"	=> esc_html__( 'Upload featured image on Hover.', 'mascot-core' ),
						'save_always'   => true,
						'admin_label'   => true,
					),
					array(
						'type'			=> 'dropdown',
						"heading"		=> esc_html__( "Choose Featured Image Size", 'mascot-core' ),
						"param_name"	=> "predefined_image_size",
						"description"	=> esc_html__( 'Default: full.', 'mascot-core' ),
						'value'			=> mascot_core_novio_get_available_image_sizes_for_vc(),
						'std'			=> 'full',
					),
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Title", 'mascot-core' ),
						"param_name"	=> "title",
						"description"	=> esc_html__( 'Eg: Projects Completed', 'mascot-core' ),
						'admin_label'   => true,
					),
					array(
						'type'			=> 'vc_link',
						'heading'		=> esc_html__( 'Link URL', 'mascot-core' ),
						'param_name'	=> 'link_url',
						'description' 	=> esc_html__( 'Add link to Button & Title.', 'mascot-core' ),
					),
					array(
						'type'			=> 'textarea_html',
						"heading"		=> esc_html__( "Paragraph", 'mascot-core' ),
						"param_name"	=> "content",
						'description'   => '',
						'value'			=> "Default text for Box Content. Lorem ipsum dolor sit amet, consectetur adipisicing elit.",
						'save_always'   => true,
					),



					//Content Options
					array(
						'type'			=> 'dropdown',
						"heading"		=> esc_html__( "Text Alignment", 'mascot-core' ),
						"param_name"	=> "text_alignment",
						"description"	=> "",
						'value'			=> mascot_core_novio_text_alignment_list(),
						'group'			=> $group_content_options
					),
					array(
						'type'			=> 'dropdown',
						"heading"		=> esc_html__( "Show Icon/Image", 'mascot-core' ),
						"param_name"	=> "show_image",
						'description'   => '',
						'value'			=> array(
							esc_html__( 'Yes', 'mascot-core' )	=> 'true',
							esc_html__( 'No', 'mascot-core' )	=> 'false'
						),
						'group'			=> $group_content_options
					),
					array(
						'type'			=> 'dropdown',
						"heading"		=> esc_html__( "Show Title", 'mascot-core' ),
						"param_name"	=> "show_title",
						'description'   => '',
						'value'			=> array(
							esc_html__( 'Yes', 'mascot-core' )	=> 'true',
							esc_html__( 'No', 'mascot-core' )	=> 'false'
						),
						'group'			=> $group_content_options
					),
					array(
						'type'			=> 'dropdown',
						"heading"		=> esc_html__( "Title Tag", 'mascot-core' ),
						"param_name"	=> "title_tag",
						'description'   => esc_html__( 'Default: H5', 'mascot-core' ),
						'value'			=> mascot_core_novio_heading_tag_list(),
						'std'			=> 'h5',
						'save_always'   => true,
						'admin_label'   => true,
						'group'			=> $group_content_options
					),
					array(
						'type'			=> 'dropdown',
						"heading"		=> esc_html__( "Show Paragraph", 'mascot-core' ),
						"param_name"	=> "show_paragraph",
						'description'   => '',
						'value'			=> array(
							esc_html__( 'Yes', 'mascot-core' )	=> 'true',
							esc_html__( 'No', 'mascot-core' )	=> 'false'
						),
						'group'			=> $group_content_options
					),
					array(
						'type'			=> 'dropdown',
						"heading"		=> esc_html__( "Show Button", 'mascot-core' ),
						"param_name"	=> "show_button",
						'description'   => '',
						'value'			=> array(
							esc_html__( 'Yes', 'mascot-core' )	=> 'true',
							esc_html__( 'No', 'mascot-core' )	=> 'false'
						),
						'group'			=> $group_content_options
					),
				)
			);
			vc_map( $vc_map );

			//Modify vc_map from themes
			if( function_exists('mascot_core_novio_sc_features_box_vc_map_modifier') ) {
				mascot_core_novio_sc_features_box_vc_map_modifier( $this->shortcode_base );
			}
		}
	}

	/**
	 * Renders shortcodes HTML
	 */
	public function render( $attr, $content = null ) {

		//Render Shortcode from themes
		if( function_exists('mascot_core_novio_sc_features_box_render') && function_exists('vc_map') ) {
			return mascot_core_novio_sc_features_box_render( $attr, $content );
		}
		
	}
}