<?php
namespace MASCOTCORENOVIO\Shortcodes\FloatingObjects;

use MASCOTCORENOVIO\Shortcodes\Lib;

/**
 * class SC_FloatingObjects
 * @package MASCOTCORENOVIO\Shortcodes\FloatingObjects;
 */
class SC_Floating_Objects implements Lib\Mascot_Core_Novio_Interface_Shortcodes {
	
	/**
	 * @var shortcode_base
	 */
	private $shortcode_base;

	/**
	 * construct
	 */
	public function __construct() {
		$this->shortcode_base = 'tm_floating_objects';
		add_action('init', array($this, 'MapShortCodeVC'), 998);
	}

	/**
	 * Returns shortcode_base for shortcode
	 */
	public function getShortCodeBase() {
		return $this->shortcode_base;
	}

	/**
	 * Maps shortcode to Visual Composer
	 */
	public function MapShortCodeVC() {
		$text_options = esc_html__( 'Text Options', 'mascot-core' );
		$footer_cite_options = esc_html__( 'Footer Cite Options', 'mascot-core' );

		if(function_exists('vc_map')) {
			$vc_map = array(
				'name'		=> esc_html__( 'Floating Objects', 'mascot-core' ),
				'base'		=>$this->shortcode_base,
				'category'	=> esc_html__( 'by TM', 'mascot-core' ),
				'icon'		=> 'mascot-vc-icons vc-icon-iconbox',
				'allowed_container_element' => 'vc_row',
				'params'	=>array(
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Custom CSS class", 'mascot-core' ),
						"param_name"	=> "custom_css_class",
						"description"	=> esc_html__( 'To style particular content element.', 'mascot-core' ),
					),
					array(
						'type'			=> 'checkbox',
						"heading"		=> esc_html__( "Visible on Mobile Devices?", 'mascot-core' ),
						"param_name"	=> "visible_mobile",
						'description'   => '',
					),

					array(
						'type'			=> 'attach_image',
						"heading"		=> esc_html__( "Floating Image", 'mascot-core' ),
						"param_name"	=> "image",
						'save_always'   => true,
						'admin_label'   => true,
					),
					array(
						'type'			=> 'dropdown',
						"heading"		=> esc_html__( "Animation Type", 'mascot-core' ),
						"param_name"	=> "animation_type",
						'value'			=> mascot_core_novio_get_animation_type(),
						'save_always'   => true,
						'admin_label'   => true,
						'std'			=> 'tm-animation-floating',
					),


					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Top (px or %)", 'mascot-core' ),
						"param_name"	=> "pos_top",
						'save_always'   => true,
						'admin_label'   => true,
					),
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Right (px or %)", 'mascot-core' ),
						"param_name"	=> "pos_right",
						'save_always'   => true,
						'admin_label'   => true,
					),
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Bottom (px or %)", 'mascot-core' ),
						"param_name"	=> "pos_bottom",
						'save_always'   => true,
						'admin_label'   => true,
					),
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Left (px or %)", 'mascot-core' ),
						"param_name"	=> "pos_left",
						'save_always'   => true,
						'admin_label'   => true,
					),
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Width (px or %)", 'mascot-core' ),
						"param_name"	=> "width",
						'save_always'   => true,
						'admin_label'   => true,
					),
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Height (px or %)", 'mascot-core' ),
						"param_name"	=> "height",
						'save_always'   => true,
						'admin_label'   => true,
					),
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Opacity", 'mascot-core' ),
						"param_name"	=> "opacity",
						"description"	=> esc_html__( 'Value between 0 to 1', 'mascot-core' ),
						'save_always'   => true,
						'admin_label'   => true,
					),
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Z Index", 'mascot-core' ),
						"param_name"	=> "z_index",
						'save_always'   => true,
						'admin_label'   => true,
					),
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Image Custom CSS class", 'mascot-core' ),
						"param_name"	=> "image_custom_css_class",
						"description"	=> esc_html__( 'To style particular content element.', 'mascot-core' ),
					),
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Image Custom Inline CSS", 'mascot-core' ),
						"param_name"	=> "image_inline_style",
						"description"	=> esc_html__( 'Example: top: 12px; left: 100px;', 'mascot-core' ),
						'admin_label'   => true,
					),

					mascot_core_novio_vc_add_css_editor(),

				)
			);
			vc_map( $vc_map );

			//Modify vc_map from themes
			if( function_exists('mascot_core_novio_sc_floating_objects_vc_map_modifier') ) {
				mascot_core_novio_sc_floating_objects_vc_map_modifier( $this->shortcode_base );
			}
		}
	}

	/**
	 * Renders shortcodes HTML
	 */
	public function render( $attr, $content = null ) {

		//Render Shortcode from themes
		if( function_exists('mascot_core_novio_sc_floating_objects_render') && function_exists('vc_map') ) {
			return mascot_core_novio_sc_floating_objects_render( $attr, $content );
		}
	}
}