<?php
namespace MASCOTCORENOVIO\Shortcodes\LineWithText;

use MASCOTCORENOVIO\Shortcodes\Lib;

/**
 * class SC_LineWithText
 * @package MASCOTCORENOVIO\Shortcodes\LineWithText;
 */
class SC_LineWithText implements Lib\Mascot_Core_Novio_Interface_Shortcodes {
	
	/**
	 * @var shortcode_base
	 */
	private $shortcode_base;

	/**
	 * construct
	 */
	public function __construct() {
		$this->shortcode_base = 'tm_line_with_text';
		add_action('init', array($this, 'MapShortCodeVC'), 998);
	}

	/**
	 * Returns shortcode_base for shortcode
	 */
	public function getShortCodeBase() {
		return $this->shortcode_base;
	}

	/**
	 * Maps shortcode to Visual Composer
	 */
	public function MapShortCodeVC() {
		$text_options = esc_html__( 'Title Text Options', 'mascot-core' );
		$line_options = esc_html__( 'Line Options', 'mascot-core' );

		if(function_exists('vc_map')) {
			$vc_map = array(
				'name'		=> esc_html__( 'Line With Text', 'mascot-core' ),
				'base'		=>$this->shortcode_base,
				'category'	=> esc_html__( 'by TM', 'mascot-core' ),
				'icon'		=> 'mascot-vc-icons vc-icon-dropcaps',
				'allowed_container_element' => 'vc_row',
				'params'	=>array(
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Custom CSS class", 'mascot-core' ),
						"param_name"	=> "custom_css_class",
						"description"	=> esc_html__( 'To style particular content element.', 'mascot-core' ),
					),

					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Title Text", 'mascot-core' ),
						"param_name"	=> "title",
					),
					array(
						'type'			=> 'dropdown',
						"heading"		=> esc_html__( "Title Text Tag", 'mascot-core' ),
						"param_name"	=> "title_tag",
						"description"	=> "",
						'value'			=> mascot_core_novio_heading_tag_list(),
						'std'			=> 'h5',
						'admin_label'   => true,
						'save_always'   => true,
						'group'			=> $text_options
					),
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Title Text Custom CSS class", 'mascot-core' ),
						"param_name"	=> "title_text_custom_css_class",
						'group'			=> $text_options
					),

					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Title Text Custom Inline Style", 'mascot-core' ),
						"param_name"	=> "title_text_inline_style",
						"description"	=> esc_html__( 'Example: color: #f1f1f1; font-size: 30px;', 'mascot-core' ),
						'admin_label'   => true,
						'group'			=> $text_options
					),

					array(
						'type'			=> 'dropdown',
						"heading"		=> esc_html__( "Horizontal Line Positioning", 'mascot-core' ),
						"param_name"	=> "horizontal_line_position",
						"description"	=> "",
						'value'			=> array(
							esc_html__( "Before Title", 'mascot-core' )	=> 'before-title',
							esc_html__( "After Title", 'mascot-core' )	=> 'after-title',
							esc_html__( "Above Title", 'mascot-core' )	=> 'above-title',
							esc_html__( "Below Title", 'mascot-core' )	=> 'below-title',
						),
						'save_always'   => true,
						'admin_label'   => true,
						'group'			=> $line_options
					),
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Horizontal Line Custom CSS class", 'mascot-core' ),
						"param_name"	=> "horizontal_line_custom_css_class",
						'group'			=> $line_options
					),
					array(
						'type'			=> 'dropdown',
						"heading"		=> esc_html__( "Horizontal Line Theme Colored?", 'mascot-core' ),
						"param_name"	=> "horizontal_line_theme_colored",
						'description'   => '',
						'value'			=> mascot_core_novio_theme_color_list_vc(),
						'group'			=> $line_options
					),

					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Horizontal Line Custom Inline Style", 'mascot-core' ),
						"param_name"	=> "horizontal_line_inline_style",
						"description"	=> esc_html__( 'Example: width: 30px; height: 10px; vertical-align: middle; background-color: #111;', 'mascot-core' ),
						'admin_label'   => true,
						'group'			=> $line_options
					),

					vc_map_add_css_animation(),
					mascot_core_novio_vc_add_css_editor(),

				)
			);
			vc_map( $vc_map );

			//Modify vc_map from themes
			if( function_exists('mascot_core_novio_sc_line_with_text_vc_map_modifier') ) {
				mascot_core_novio_sc_line_with_text_vc_map_modifier( $this->shortcode_base );
			}
		}
	}

	/**
	 * Renders shortcodes HTML
	 */
	public function render( $attr, $content = null ) {

		//Render Shortcode from themes
		if( function_exists('mascot_core_novio_sc_line_with_text_render') && function_exists('vc_map') ) {
			return mascot_core_novio_sc_line_with_text_render( $attr, $content );
		}
		
	}
}