<?php
namespace MASCOTCORENOVIO\Shortcodes\LocationMarker;

use MASCOTCORENOVIO\Shortcodes\Lib;

/**
 * class SC_Location_Marker
 * @package MASCOTCORENOVIO\Shortcodes\LocationMarker;
 */
class SC_Location_Marker implements Lib\Mascot_Core_Novio_Interface_Shortcodes {
	
	/**
	 * @var shortcode_base
	 */
	private $shortcode_base;

	/**
	 * construct
	 */
	public function __construct() {
		$this->shortcode_base = 'tm_location_marker';
		add_action('init', array($this, 'MapShortCodeVC'), 998);
	}

	/**
	 * Returns shortcode_base for shortcode
	 */
	public function getShortCodeBase() {
		return $this->shortcode_base;
	}

	/**
	 * Maps shortcode to Visual Composer
	 */
	public function MapShortCodeVC() {
		$title_options = esc_html__( 'Title Options', 'mascot-core' );
		$group_content_options = esc_html__( 'Content Options', 'mascot-core' );

		if(function_exists('vc_map')) {
			$vc_map = array(
				'name'		=> esc_html__( 'Location Marker', 'mascot-core' ),
				'base'		=>$this->shortcode_base,
				'category'	=> esc_html__( 'by TM', 'mascot-core' ),
				'icon'		=> 'mascot-vc-icons vc-icon-before-after',
				'allowed_container_element' => 'vc_row',
				'params'	=>array(
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Custom CSS class", 'mascot-core' ),
						"param_name"	=> "custom_css_class",
						"description"	=> esc_html__( 'To style particular content element.', 'mascot-core' ),
					),
					array(
						'type'			=> 'attach_image',
						"heading"		=> esc_html__( "Background Image", 'mascot-core' ),
						"param_name"	=> "bg_image",
						"description"	=> esc_html__( 'Upload background image.', 'mascot-core' ),
						'save_always'   => true,
						'admin_label'   => true,
					),

					array(
						'type' => 'param_group',
						'heading' => esc_html__( 'Marker Icons', 'js_composer' ),
						'param_name' => 'marker_icons',
						'value' => rawurlencode( wp_json_encode( array(
							array(
								'title' => esc_html__( 'Marker One', 'js_composer' ),
							),
							array(
								'title' => esc_html__( 'Marker Two', 'js_composer' ),
								'target_id' => 'marker2',
								'icon' => '',
							),
						) ) ),
						'params' => array(
								array(
									'type'			=> 'textfield',
									"heading"		=> esc_html__( "Marker Title", 'mascot-core' ),
									"param_name"	=> "title",
									'admin_label'   => true,
								),
								array(
									'type'			=> 'textarea',
									"heading"		=> esc_html__( "Marker Popup Text", 'mascot-core' ),
									"param_name"	=> "marker_text",
									'admin_label'   => true,
								),
								array(
									'type'			=> 'textfield',
									"heading"		=> esc_html__( "Marker Custom Inline Style", 'mascot-core' ),
									"param_name"	=> "marker_inline_style",
									"description"	=> esc_html__( 'Example: top: 12px; left: 100px;', 'mascot-core' ),
									'admin_label'   => true,
								),
								array(
									'type'			=> 'textfield',
									"heading"		=> esc_html__( "Marker Custom CSS class", 'mascot-core' ),
									"param_name"	=> "marker_custom_css_class",
									"description"	=> esc_html__( 'To style this marker.', 'mascot-core' ),
								),
						),
						'callbacks' => array(
							'after_add' => 'vcChartParamAfterAddCallback',
						),
					),

					mascot_core_novio_vc_add_css_editor(),
				)
			);
			vc_map( $vc_map );

			//Modify vc_map from themes
			if( function_exists('mascot_core_novio_sc_location_marker_vc_map_modifier') ) {
				mascot_core_novio_sc_location_marker_vc_map_modifier( $this->shortcode_base );
			}
		}
	}

	/**
	 * Renders shortcodes HTML
	 */
	public function render( $attr, $content = null ) {

		//Render Shortcode from themes
		if( function_exists('mascot_core_novio_sc_location_marker_render') && function_exists('vc_map') ) {
			return mascot_core_novio_sc_location_marker_render( $attr, $content );
		}
		
	}
}