<?php
namespace MASCOTCORENOVIO\Shortcodes\NavTabsPricing;

use MASCOTCORENOVIO\Shortcodes\Lib;

/**
 * class SC_Nav_Tabs_Pricing
 * @package MASCOTCORENOVIO\Shortcodes\NavTabsPricing;
 */
class SC_Nav_Tabs_Pricing implements Lib\Mascot_Core_Novio_Interface_Shortcodes {
	
	/**
	 * @var shortcode_base
	 */
	private $shortcode_base;

	/**
	 * construct
	 */
	public function __construct() {
		$this->shortcode_base = 'tm_nav_tabs_pricing';
		add_action('init', array($this, 'MapShortCodeVC'), 998);
	}

	/**
	 * Returns shortcode_base for shortcode
	 */
	public function getShortCodeBase() {
		return $this->shortcode_base;
	}

	/**
	 * Maps shortcode to Visual Composer
	 */
	public function MapShortCodeVC() {
    
		if(function_exists('vc_map')) {
			$vc_map = array(
				'name'		=> esc_html__( 'Nav Tabs Pricing', 'mascot-core' ),
				'base'		=>$this->shortcode_base,
				'category'	=> esc_html__( 'by TM', 'mascot-core' ),
				'icon'		=> 'mascot-vc-icons vc-icon-nav-tab-pricing',
				'as_parent' => array('only' => 'tm_nav_tabs_pricing_item'),
				"js_view" => 'VcColumnView',
				'params'	=>array(
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Custom CSS class", 'mascot-core' ),
						"param_name"	=> "custom_css_class",
						"description"	=> esc_html__( 'To style particular content element.', 'mascot-core' ),
					),



					array(
						'type' => 'param_group',
						'heading' => esc_html__( 'Nav Tab Titles', 'js_composer' ),
						'param_name' => 'nav_tab_titles',
						'value' => rawurlencode( wp_json_encode( array(
							array(
								'title' => esc_html__( 'Monthly', 'js_composer' ),
								'subtitle' => esc_html__( '20% Off!', 'js_composer' ),
								'target_id' => 'pricing-navtab1',
								'active_tab' => 'true',
							),
							array(
								'title' => esc_html__( 'Yearly', 'js_composer' ),
								'subtitle' => '',
								'target_id' => 'pricing-navtab2',
								'active_tab' => '',
							),
						) ) ),
						'params' => array(
								array(
									'type'			=> 'textfield',
									"heading"		=> esc_html__( "Title", 'mascot-core' ),
									"param_name"	=> "title",
									'admin_label'   => true,
								),
								array(
									'type'			=> 'textfield',
									"heading"		=> esc_html__( "Sub Title", 'mascot-core' ),
									"param_name"	=> "subtitle",
								),
								array(
									'type'			=> 'textfield',
									"heading"		=> esc_html__( "Target Tab Content ID", 'mascot-core' ),
									"param_name"	=> "target_id",
								),

								array(
									'type'			=> 'checkbox',
									"heading"		=> esc_html__( "Make this Tab Active?", 'mascot-core' ),
									"param_name"	=> "active_tab",
									'std'			=> 'false',
								),
						),
						'callbacks' => array(
							'after_add' => 'vcChartParamAfterAddCallback',
						),
					),
					array(
						'type'			=> 'dropdown',
						"heading"		=> esc_html__( "Tab Button Style", 'mascot-core' ),
						"param_name"	=> "tab_btn_style",
						'value'			=> array(
							esc_html__( 'Basic', 'mascot-core' )			=> 'nav-tab-btn-basic',
							esc_html__( 'Switch Button', 'mascot-core' )	=> 'nav-tab-btn-switch',
							esc_html__( 'Bullet Button', 'mascot-core' )	=> 'nav-tab-btn-bullet',
						),
						'save_always'   => true,
					),

					mascot_core_novio_vc_add_css_editor(),

				)
			);
			vc_map( $vc_map );

			//Modify vc_map from themes
			if( function_exists('mascot_core_novio_sc_nav_tabs_pricing_vc_map_modifier') ) {
				mascot_core_novio_sc_nav_tabs_pricing_vc_map_modifier( $this->shortcode_base );
			}
		}
	}

	/**
	 * Renders shortcodes HTML
	 */
	public function render( $attr, $content = null ) {

		//Render Shortcode from themes
		if( function_exists('mascot_core_novio_sc_nav_tabs_pricing_render') && function_exists('vc_map') ) {
			return mascot_core_novio_sc_nav_tabs_pricing_render( $attr, $content );
		}
		
	}
}