<?php
namespace MASCOTCORENOVIO\Shortcodes\SocialLinks;

use MASCOTCORENOVIO\Shortcodes\Lib;

/**
 * class SC_Social_Links
 * @package MASCOTCORENOVIO\Shortcodes\SocialLinks;
 */
class SC_Social_Links implements Lib\Mascot_Core_Novio_Interface_Shortcodes {
	
	/**
	 * @var shortcode_base
	 */
	private $shortcode_base;

	/**
	 * construct
	 */
	public function __construct() {
		$this->shortcode_base = 'tm_social_links';
		add_action('init', array($this, 'MapShortCodeVC'), 998);
	}

	/**
	 * Returns shortcode_base for shortcode
	 */
	public function getShortCodeBase() {
		return $this->shortcode_base;
	}

	/**
	 * Maps shortcode to Visual Composer
	 */
	public function MapShortCodeVC() {
		$group_social_urls = esc_html__( 'Social URLs', 'mascot-core' );
		$group_content_options = esc_html__( 'Content Options', 'mascot-core' );

		if(function_exists('vc_map')) {
			$vc_map = array(
				'name'		=> esc_html__( 'Social Links', 'mascot-core' ),
				'base'		=>$this->shortcode_base,
				'category'	=> esc_html__( 'by TM', 'mascot-core' ),
				'icon'		=> 'mascot-vc-icons vc-icon-twitter',
				'allowed_container_element' => 'vc_row',
				'params'	=>array(
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Custom CSS class", 'mascot-core' ),
						"param_name"	=> "custom_css_class",
						"description"	=> esc_html__( 'To style particular content element.', 'mascot-core' ),
					),
					array(
						'type'			=> 'dropdown',
						"heading"		=> esc_html__( "Alignment", 'mascot-core' ),
						"param_name"	=> "text_alignment",
						"description"	=> "",
						'value'			=> mascot_core_novio_text_alignment_list(),
						'save_always'   => true,
					),
					array(
						'type'			=> 'dropdown',
						"heading"		=> esc_html__( "Icon Style", 'mascot-core' ),
						"param_name"	=> "icon_style",
						'desc'		  => '',
						'value'			=> array(
							esc_html__( 'Circled', 'mascot-core' )		=>   'icon-circled',
							esc_html__( 'Rounded', 'mascot-core' )		=>   'icon-rounded',
						),
						'save_always'   => true,
						'admin_label'   => true,
					),
					array(
						'type'			=> 'dropdown',
						"heading"		=> esc_html__( "Icon Size", 'mascot-core' ),
						"param_name"	=> "icon_size",
						'desc'		  => '',
						'value'			=> array(
							esc_html__( 'Default', 'mascot-core' )		=>   '',
							esc_html__( 'Extra Small', 'mascot-core' )	=>   'icon-xs',
							esc_html__( 'Small', 'mascot-core' )		=>   'icon-sm',
							esc_html__( 'Medium', 'mascot-core' )		=>   'icon-md',
							esc_html__( 'Large', 'mascot-core' )		=>   'icon-lg',
							esc_html__( 'Extra Large', 'mascot-core' )	=>   'icon-xl',
						),
						'save_always'   => true,
						'admin_label'   => true,
					),
					array(
						'type'			=> 'checkbox',
						"heading"		=> esc_html__( "Make Icon Outlined?", 'mascot-core' ),
						"param_name"	=> "icon_outlined",
						'desc'		  => '',
						'admin_label'   => true,
						'std'			=> true,
					),
					array(
						'type'			=> 'dropdown',
						"heading"		=> esc_html__( "Icon Color", 'mascot-core' ),
						"param_name"	=> "icon_color",
						'desc'		  => '',
						'value'			=> array(
							esc_html__( 'Dark', 'mascot-core' )		=>   'icon-dark',
							esc_html__( 'Light', 'mascot-core' )	=>   'icon-light',
						),
						'save_always'   => true,
						'admin_label'   => true,
					),
					array(
						'type'			=> 'dropdown',
						"heading"		=> esc_html__( "Make Icon Theme Colored?", 'mascot-core' ),
						"param_name"	=> "icon_theme_colored",
						'desc'		  => '',
						'value'			=> mascot_core_novio_theme_color_list_vc(),
						'admin_label'   => true,
					),
					array(
						'type'			=> 'dropdown',
						"heading"		=> esc_html__( "Link Target", 'mascot-core' ),
						"param_name"	=> "target",
						'value' => array(
							esc_html__( 'New Tab (Blank)', 'mascot-core' )	=> '_blank',
							esc_html__( 'Self', 'mascot-core' )	=> '_self',
						),
						'save_always'   => true,
					),



					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Twitter URL", 'mascot-core' ),
						"param_name"	=> "url_twitter",
						'group'			=> $group_social_urls
					),
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Facebook URL", 'mascot-core' ),
						"param_name"	=> "url_facebook",
						'group'			=> $group_social_urls
					),
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Youtube URL", 'mascot-core' ),
						"param_name"	=> "url_youtube",
						'group'			=> $group_social_urls
					),


					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Linkedin URL", 'mascot-core' ),
						"param_name"	=> "url_linkedin",
						'group'			=> $group_social_urls
					),
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Instagram URL", 'mascot-core' ),
						"param_name"	=> "url_instagram",
						'group'			=> $group_social_urls
					),
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Tumblr URL", 'mascot-core' ),
						"param_name"	=> "url_tumblr",
						'group'			=> $group_social_urls
					),


					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "VK URL", 'mascot-core' ),
						"param_name"	=> "url_vk",
						'group'			=> $group_social_urls
					),
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Pinterest URL", 'mascot-core' ),
						"param_name"	=> "url_pinterest",
						'group'			=> $group_social_urls
					),
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Reddit URL", 'mascot-core' ),
						"param_name"	=> "url_reddit",
						'group'			=> $group_social_urls
					),
				)
			);
			vc_map( $vc_map );

			//Modify vc_map from themes
			if( function_exists('mascot_core_novio_sc_social_links_vc_map_modifier') ) {
				mascot_core_novio_sc_social_links_vc_map_modifier( $this->shortcode_base );
			}
		}
	}

	/**
	 * Renders shortcodes HTML
	 */
	public function render( $attr, $content = null ) {

		//Render Shortcode from themes
		if( function_exists('mascot_core_novio_sc_social_links_render') && function_exists('vc_map') ) {
			return mascot_core_novio_sc_social_links_render( $attr, $content );
		}
		
	}
}